OC.L10N.register(
    "core",
    {
    "Please select a file." : "Prosím, vyberte súbor.",
    "File is too big" : "Súbor je príliš veľký",
    "The selected file is not an image." : "Vybraný súbor nie je obrázok.",
    "The selected file cannot be read." : "Vybraný súbor nie je možné čítať.",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor bol nahraný iba čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk",
    "A PHP extension stopped the file upload" : "Rozšírenie PHP zastavilo nahrávanie súboru",
    "Invalid file provided" : "Zadaný neplatný súbor",
    "No image or file provided" : "Obrázok alebo súbor nebol zadaný",
    "Unknown filetype" : "Neznámy typ súboru",
    "An error occurred. Please contact your admin." : "Vyskytla sa chyba.\nProsím, kontaktujte svojho správcu.\n\t",
    "Invalid image" : "Chybný obrázok",
    "State token does not match" : "Príznak stavu nesúhlasí",
    "Invalid app password" : "Neplatné heslo aplikácie",
    "Could not complete login" : "Nie je možné dokončiť prihlásenie",
    "State token missing" : "Chýba stavový token",
    "Your login token is invalid or has expired" : "Váš prihlasovací token je neplatný alebo jeho platnosť skončila",
    "Please use original client" : "Použite prosím originálneho klienta",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Toto komunitné vydanie Nextcloud nie je podporované a push upozornenia nie sú k dispozícii.",
    "Login" : "Prihlásiť sa",
    "Unsupported email length (>255)" : "Dĺžka emailovej správy nie je podporovaná (>255)",
    "Password reset is disabled" : "Obnovenie hesla nie je povolené",
    "Could not reset password because the token is expired" : "Nepodarilo sa obnoviť heslo, pretože platnosť tokenu uplynula",
    "Could not reset password because the token is invalid" : "Nepodarilo sa obnoviť heslo, pretože token nie je platný",
    "Password is too long. Maximum allowed length is 469 characters." : "Heslo je príliš dlhé. Maximálna povolená dĺžka je 469 znakov.",
    "%s password reset" : "reset hesla %s",
    "Password reset" : "Obnovenie hesla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúce tlačidlo. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúci odkaz. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
    "Reset your password" : "Vytvoriť nové heslo",
    "The given provider is not available" : "Zadaný poskytovateľ nie je dostupný",
    "Task not found" : "Úloha nebola nájdená",
    "Internal error" : "Interná chyba",
    "Not found" : "Nenájdené",
    "Node is locked" : "Uzol je uzamknutý",
    "Bad request" : "Neplatná požiadavka",
    "Input text is too long" : "Vstupný text je príliš dlhý.",
    "Requested task type does not exist" : "Vyžiadaný typ úlohy neexistuje",
    "Necessary language model provider is not available" : "Potrebný poskytovateľ jazykového modelu nie je dostupný",
    "No text to image provider is available" : "Nie je dostupný žiadny poskytovateľ služby \"text na obrázok\"",
    "Image not found" : "Obrázok nenájdený",
    "No translation provider available" : "Nie je dostupný žiadny poskytovateľ prekladu",
    "Could not detect language" : "Nepodarilo sa zistiť jazyk",
    "Unable to translate" : "Nie je možné preložiť",
    "No valid filters provided" : "Žiadne platné filtre poskytnuté",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Krok opravy:",
    "Repair info:" : "Informácie o oprave:",
    "Repair warning:" : "Varovanie o oprave:",
    "Repair error:" : "Chyba opravy:",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Niektoré odkazy so sprístupnením boli odstránené.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvôli bezpečnostnej chyba sme museli odstrániť niektoré z vašich odkazov pre zdieľanie. Pre viac informácií nasledujte tento link.",
    "The account limit of this instance is reached." : "Limit pre počet užívateľov pre túto inštanciu bol dosiahnutý.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Zadajte svoj kľúč predplatného v aplikácii podpory, aby ste zvýšili limit pre množstvo účtov. To vám tiež poskytuje všetky ďalšie výhody, ktoré Nextcloud Enterprise ponúka a je vysoko odporúčaný pre prevádzku vo firemnom prostredí.",
    "Learn more ↗" : "Viac informácií ↗",
    "Preparing update" : "Pripravuje sa aktualizácia",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Prosím, použite aktualizáciu z príkazového riadka, pretože aktualizácia cez prehliadač je zakázaná vo vašom config.php.",
    "Turned on maintenance mode" : "Mód údržby je zapnutý",
    "Turned off maintenance mode" : "Mód údržby je vypnutý",
    "Maintenance mode is kept active" : "Režim údržby je stále aktívny",
    "Updating database schema" : "Aktualizuje sa schéma databázy",
    "Updated database" : "Databáza je aktualizovaná",
    "Update app \"%s\" from App Store" : "Aktualizovať aplikáciu \"%s\" z obchodu",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontroluje sa, či je možné aktualizovať schému databázy pre %s (to môže trvať dlhší čas v závislosti na veľkosti databázy)",
    "Updated \"%1$s\" to %2$s" : "Aktualizované \"%1$s\" na %2$s",
    "Set log level to debug" : "Nastaviť úroveň záznamu na ladenie",
    "Reset log level" : "Obnoviť úroveň záznamu",
    "Starting code integrity check" : "Začína kontrola integrity kódu",
    "Finished code integrity check" : "Kontrola integrity kódu ukončená",
    "%s (incompatible)" : "%s (nekompatibilná)",
    "The following apps have been disabled: %s" : "Nasledujúce aplikácie boli vypnuté: %s",
    "Already up to date" : "Už aktuálne",
    "Windows Command Script" : "Skript príkazov Windows",
    "Electronic book document" : "Dokument elektronickej knihy",
    "TrueType Font Collection" : "Kolekcia fontov TrueType",
    "Web Open Font Format" : "Web Open Font Format",
    "GPX geographic data" : "GPX geografické dáta",
    "Gzip archive" : "Gzip archív",
    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
    "Java source code" : "Zdrojový kód Java",
    "JavaScript source code" : "Zdrojový kód Javascriptu",
    "JSON document" : "Dokument JSON",
    "Microsoft Access database" : "Databáza Microsoft Access",
    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
    "Microsoft Word document" : "Dokument Microsoft Word",
    "Unknown" : "Neznámy",
    "PDF document" : "PDF dokument",
    "PostScript document" : "Dokument PostScriptu",
    "RSS summary" : "Zhrnutie RSS",
    "Android package" : "Balík pre Android",
    "KML geographic data" : "KML geografické dáta",
    "KML geographic compressed data" : "KML komprimované geografické dáta",
    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
    "Excel spreadsheet" : "Tabuľka Excelu",
    "Excel add-in" : "Rozšírenie Excelu",
    "Excel 2007 binary spreadsheet" : "Binárna tabuľka Excel 2007",
    "Excel spreadsheet template" : "Šablóna tabuľky Excel",
    "Outlook Message" : "Správa Outlooku",
    "PowerPoint presentation" : "PowerPoint prezentácia",
    "PowerPoint add-in" : "Rozšírenie PowerPointu",
    "PowerPoint presentation template" : "Šablóna prezentácie PowerPoint",
    "Word document" : "Dokument Wordu",
    "ODF formula" : "Vzorec ODF",
    "ODG drawing" : "Kresba ODG",
    "ODG drawing (Flat XML)" : "Výkres ODG (Čisté XML)",
    "ODG template" : "Šablóna ODG",
    "ODP presentation" : "Prezentácia ODP",
    "ODP presentation (Flat XML)" : "Prezentácia ODP (Čisté XML)",
    "ODP template" : "Šablóna ODP",
    "ODS spreadsheet" : "Tabuľka ODS",
    "ODS spreadsheet (Flat XML)" : "Tabuľka ODS (Čisté XML)",
    "ODS template" : "Šablóna ODS",
    "ODT document" : "Dokument ODT",
    "ODT document (Flat XML)" : "Dokument ODT (Čisté XML)",
    "ODT template" : "Šablóna ODT",
    "PowerPoint 2007 presentation" : "Prezentácia PowerPointu 2007",
    "PowerPoint 2007 show" : "Prezentácia PowerPointu 2007",
    "PowerPoint 2007 presentation template" : "Šablóna prezentácie PowerPointu 2007",
    "Excel 2007 spreadsheet" : "Tabuľka Excelu 2007",
    "Excel 2007 spreadsheet template" : "Šablóna tabuľky Excelu 2007",
    "Word 2007 document" : "Dokument Wordu 2007",
    "Word 2007 document template" : "Šablóna dokumentu Wordu 2007",
    "Microsoft Visio document" : "Dokument Microsoft Visio",
    "WordPerfect document" : "Dokument WordPerfectu",
    "7-zip archive" : "7-zip archív",
    "Blender scene" : "Scéna Blenderu",
    "Bzip2 archive" : "Bzip2 archív",
    "Debian package" : "Balík Debianu",
    "FictionBook document" : "Dokument FictionBook",
    "Unknown font" : "Neznáme písmo",
    "Krita document" : "Dokument Krita",
    "Mobipocket e-book" : "E-kniha Mobipocket",
    "Windows Installer package" : "Inštalačný balík Windows",
    "Perl script" : "Skript Perlu",
    "PHP script" : "Skript PHP",
    "Tar archive" : "Archív TAR",
    "XML document" : "Dokument XML",
    "YAML document" : "Dokument YAML",
    "Zip archive" : "Zip archív",
    "Zstandard archive" : "Zstandartd archív",
    "AAC audio" : "AAC audio",
    "FLAC audio" : "FLAC audio",
    "MPEG-4 audio" : "MPEG-4 audio",
    "MP3 audio" : "MP3 audio",
    "Ogg audio" : "Ogg audio",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe standard Audio",
    "WebM audio" : "WebM audio",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
    "Windows BMP image" : "Obrázok Windows BMP",
    "Better Portable Graphics image" : "Lepší prenosný grafický obrázok",
    "EMF image" : "EMF obrázok",
    "GIF image" : "GIF obrázok",
    "HEIC image" : "HEIC obrázok",
    "HEIF image" : "HEIF obrázok",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 obrázok",
    "JPEG image" : "JPEG obrázok",
    "PNG image" : "PNG obrázok",
    "SVG image" : "SVG obrázok",
    "Truevision Targa image" : "Truevision Targa obrázok",
    "TIFF image" : "TIFF obrázok",
    "WebP image" : "WebP obrázok",
    "Digital raw image" : "Digital raw obrázok",
    "Windows Icon" : "Windows ikona",
    "Email message" : "E-mailová správa",
    "VCS/ICS calendar" : "VCS/ICS kalendár",
    "CSS stylesheet" : "CSS štýlový list",
    "CSV document" : "CSV dokument",
    "HTML document" : "HTML dokument",
    "Markdown document" : "Markdown dokument",
    "Org-mode file" : "Org-mode súbor",
    "Plain text document" : "Dokument v čistom texte",
    "Rich Text document" : "Dokument vo formátovanom texte",
    "Electronic business card" : "Elektronická vizitka",
    "C++ source code" : "C++ zdrojový kód",
    "LDIF address book" : "Adresár LDIF",
    "NFO document" : "NFO dokument",
    "PHP source" : "PHP zdroj",
    "Python script" : "Python skript",
    "ReStructuredText document" : "ReStructuredText dokument",
    "3GPP multimedia file" : "3GPP multimediálny súbor",
    "MPEG video" : "MPEG video",
    "DV video" : "DV video",
    "MPEG-2 transport stream" : "MPEG-2 transportný tok",
    "MPEG-4 video" : "MPEG-4 video",
    "Ogg video" : "Ogg video",
    "QuickTime video" : "QuickTime video",
    "WebM video" : "WebM video",
    "Flash video" : "Flash video",
    "Matroska video" : "Matroska video",
    "Windows Media video" : "Windows Media video",
    "AVI video" : "AVI video",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
    "Update to {version}" : "Aktualizuj na {version}",
    "An error occurred." : "Vyskytla sa chyba.",
    "Please reload the page." : "Obnovte prosím stránku.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizácia neprebehla úspešne. Pre viac informácií <a href=\"{url}\">navštívte príspevok na našom fóre</a>, ktorý pokrýva tento problém.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizácia bola neúspešná. Oznámte prosím tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunite Nextcloud</a>.",
    "Continue to {productName}" : "Pokračovať na {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizácia prebehla úspešne. O %n sekundu budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekundy budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}."],
    "Done" : "Hotovo",
    "Applications menu" : "Ponuka aplikácií",
    "Apps" : "Aplikácie",
    "More apps" : "Viac aplikácií",
    "_{count} notification_::_{count} notifications_" : ["{count} upozornenie","{count} upozornenia","{count} upozornení","{count} upozornenia"],
    "No" : "Nie",
    "Yes" : "Áno",
    "App password" : "Heslo aplikácie",
    "Grant access" : "Povoliť prístup",
    "The remote URL must include the user." : "Vzdialená adresa URL musí zahŕňať užívateľa.",
    "Invalid remote URL." : "Neplatná vzdialená adresa URL.",
    "Failed to add the public link to your Nextcloud" : "Pridanie verejne dostupného odkazu do vášho Nextcloud zlyhalo",
    "Federated user" : "Združený užívateľ",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "Vytvoriť zdieľanie",
    "Direct link copied" : "Priamy odkaz skopírovaný",
    "Please copy the link manually:" : "Prosím skopírujte odkaz manuálne:",
    "Custom date range" : "Vlastné rozpätie dátumov",
    "Pick start date" : "Vyberte dátum začiatku",
    "Pick end date" : "Vyberte dátum ukončenia",
    "Search in date range" : "Hľadať v rozsahu dátumov",
    "Search in current app" : "Hľadať v aktuálnej aplikácii",
    "Clear search" : "Vymazať hľadanie",
    "Search everywhere" : "Hľadať všade",
    "Searching …" : "Vyhľadáva sa …",
    "Start typing to search" : "Začnite písať pre vyhľadanie",
    "Minimum search length is {minSearchLength} characters" : "Minimálna dĺžka vyhľadávania je {minSearchLength} znakov",
    "No matching results" : "Žiadne zhodujúce výsledky",
    "Today" : "Dnes",
    "Last 7 days" : "Posledných 7 dní",
    "Last 30 days" : "Posledných 30 dní",
    "This year" : "Tento rok",
    "Last year" : "Minulý rok",
    "Between {startDate} and {endDate}" : "Medzi {startDate} a {endDate}",
    "Unified search" : "Jednotné vyhľadávanie",
    "Search apps, files, tags, messages" : "Hľadať aplikácie, súbory, štítky a správy",
    "Places" : "Miesta",
    "Date" : "Dátum",
    "Search people" : "Hľadať ľudí",
    "People" : "Ľudia",
    "Filter in current view" : "Filter v aktuálnom zobrazení",
    "Search connected services" : "Vyhľadávať pripojené služby",
    "Results" : "Výsledky",
    "Load more results" : "Načítať viac výsledkov",
    "Search in" : "Hľadať v",
    "Partial matches" : "Čiastočné zhody",
    "Log in" : "Prihlásiť sa",
    "Logging in …" : "Prebieha prihlasovanie …",
    "Log in to {productName}" : "Prihlásiť sa do {productName}u",
    "Wrong login or password." : "Nesprávne meno alebo heslo.",
    "This account is disabled" : "Tento účet je deaktivovaný",
    "Too many incorrect login attempts. Please try again in 30 seconds." : "Príliš veľa neúspešných pokusov o prihlásenie. Skúste to znova o 30 sekúnd.",
    "Account name or email" : "Názov účtu alebo e-mail",
    "Account name" : "Názov účtu",
    "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
    "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
    "Session error" : "Chyba relácie",
    "It appears your session token has expired, please refresh the page and try again." : "Zdá sa, že platnosť vášho tokenu relácie vypršala, obnovte stránku a skúste to znova.",
    "An internal error occurred." : "Došlo k vnútornej chybe.",
    "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
    "Password" : "Heslo",
    "Remember me" : "Zapamätať si ma",
    "Log in with a device" : "Prihlásiť sa pomocou zariadenia",
    "Login or email" : "Prihlasovacie meno alebo email",
    "Your account is not setup for passwordless login." : "Váš účet nie je nastavený pre bezheslové overovanie.",
    "Your connection is not secure" : "Pripojenie nie je bezpečné",
    "Passwordless authentication is only available over a secure connection." : "Bezheslové overovanie je dostupné len pomocou šifrovaného pripojenia.",
    "Browser not supported" : "Prehliadač nie je podporovaný",
    "Passwordless authentication is not supported in your browser." : "Bezheslové overovanie nie je vo vašom prehliadači podporované.",
    "Reset password" : "Obnovenie hesla",
    "Back to login" : "Späť na prihlásenie",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ak tento účet existuje, na jeho e-mailovú adresu bola odoslaná správa pre obnovenie hesla. Ak ju nedostanete, overte si svoju e-mailovú adresu a/alebo Login, skontrolujte svoje spam/junk priečinky alebo požiadajte o pomoc miestneho administrátora.",
    "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
    "Password cannot be changed. Please contact your administrator." : "Heslo nemožno zmeniť. Kontaktujte prosím vášho administrátora.",
    "New password" : "Nové heslo",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše súbory sú šifrované. Po obnovení hesla nebude možné dostať sa k vašim údajom. Ak neviete, čo robíte, kontaktujte vášho administrátora a až potom pokračujte. Naozaj chcete pokračovať?",
    "I know what I'm doing" : "Viem, čo robím",
    "Resetting password" : "Obnovuje sa heslo",
    "Schedule work & meetings, synced with all your devices." : "Naplánujte si prácu a stretnutia, synchronizované so všetkými vašimi zariadeniami.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Udržujte si údaje o svojich kolegoch a priateľoch na jednom mieste bez hrozby úniku ich súkromných informácií tretím stranám.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchá apka pre čítanie e-mailov, prepojená so Súbormi, Kontaktami a Kalendárom.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Konverzácie, videohovory, zdieľanie obrazovky, online stretnutia a webové konferencie - vo vašom prehliadači a s mobilnými aplikáciami.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kolaboratívne dokumenty, tabuľky a prezentácie postavené na Collabora Online.",
    "Distraction free note taking app." : "Aplikácia pre písanie poznámok bez rozptyľovania.",
    "Recommended apps" : "Odporúčané apky",
    "Loading apps …" : "Načítavanie aplikácií ...",
    "Could not fetch list of apps from the App Store." : "Nepodarilo sa načítať zoznam apiek z Obchodu s aplikáciami.",
    "App download or installation failed" : "Nepodarilo sa prevziať alebo nainštalovať apku",
    "Cannot install this app because it is not compatible" : "Táto apka sa nedá nainštalovať, pretože nie je kompatibilná",
    "Cannot install this app" : "Táto aplikácia sa nedá nainštalovať",
    "Skip" : "Preskočiť",
    "Installing apps …" : "Inštalácia aplikácií …",
    "Install recommended apps" : "Nainštalovať odporúčané apky",
    "Online" : "Pripojený",
    "Away" : "Preč",
    "Busy" : "Zaneprázdnený",
    "Do not disturb" : "Nerušiť",
    "Mute all notifications" : "Stlmiť všetky upozornenia",
    "Invisible" : "Neviditeľný",
    "Appear offline" : "Zdá sa byť offline",
    "Avatar of {displayName}" : "Avatar užívateľa {displayName}",
    "Settings menu" : "Menu nastavení",
    "Loading your contacts …" : "Načítavanie vašich kontaktov...",
    "Looking for {term} …" : "Hľadá sa {term}...",
    "Search contacts" : "Prehľadať kontakty",
    "Reset search" : "Vynuluj vyhľadávanie",
    "Search contacts …" : "Prehľadať kontakty ...",
    "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
    "No contacts found" : "Kontakty nenájdené",
    "Show all contacts" : "Zobraziť všetky kontakty",
    "Install the Contacts app" : "Inštalovať aplikáciu Kontakty",
    "Search" : "Hľadať",
    "No results for {query}" : "Žiadne výsledky pre {query}",
    "Press Enter to start searching" : "Stlačte Enter pre spustenie hľadania",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Pre vyhľadávanie zadajte aspoň {minSearchLength} znak","Pre vyhľadávanie zadajte aspoň {minSearchLength} znaky","Pre vyhľadávanie zadajte aspoň {minSearchLength} znakov","Pre vyhľadávanie zadajte aspoň {minSearchLength} znakov"],
    "An error occurred while searching for {type}" : "Počas hľadania {type} sa vyskytla chyba",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Hľadanie sa začína, keď začnete písať a výsledky môžete dosiahnuť pomocou šípiek.",
    "Search for {name} only" : "Hľadať iba {name}",
    "Loading more results …" : "Načítava sa viac výsledkov …",
    "Forgot password?" : "Zabudli ste heslo?",
    "Back to login form" : "Späť na prihlásenie",
    "Back" : "Späť",
    "Login form is disabled." : "Prihlasovací formulár je vypnutý.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prihlasovanie do Nextcloud je zakázané. Použite inú možnosť prihlásenia, ak je k dispozícii, alebo kontaktujte svojho administrátora.",
    "Connect to your account" : "Pripojte sa k svojmu účtu",
    "Security warning" : "Bezpečnostné varovanie",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ak sa nesnažíte nastaviť nové zariadenie alebo aplikáciu, niekto sa vás pokúša oklamať, aby ste im poskytli prístup k vašim údajom. V takom prípade nepokračujte a obráťte sa na správcu systému.",
    "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
    "Account connected" : "Účet pripojený",
    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
    "You can close this window." : "Toto okno už môžete zatvoriť.",
    "Account access" : "Prístup k účtu",
    "More actions" : "Viac akcií",
    "User menu" : "Používateľské menu",
    "Your guest name: {user}" : "Vaše meno hosťa: {user}",
    "You are currently not identified." : "Momentálne nie ste identifikovaní.",
    "Set public name" : "Nastaviť verejné meno",
    "Change public name" : "Zmeniť verejné meno",
    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
    "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
    "Submit" : "Odoslať",
    "Please type in your email address to request a temporary password" : "Prosím zadajte vašu e-mailovú adresu pre získanie dočasného hesla",
    "Password sent!" : "Heslo odoslané!",
    "You are not authorized to request a password for this share" : "Nemáte oprávnenie žiadať o heslo pre toto zdieľanie",
    "Email address" : "E-mailová adresa",
    "Request password" : "Vyžiadať heslo",
    "Forgot password" : "Zabudnuté heslo",
    "Password is too weak" : "Heslo je príliš jednoduché",
    "Password is weak" : "Heslo je jednoduché",
    "Password is average" : "Heslo je priemerné",
    "Password is strong" : "Heslo je silné",
    "Password is very strong" : "Heslo je veľmi silné",
    "Password is extremely strong" : "Heslo je extrémne silné",
    "Unknown password strength" : "Neznáma sila hesla",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Váš priečinok s dátami a súbormi je pravdepodobne dostupný z internetu, pretože súbor <code>.htaccess</code> nefunguje.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pre informácie o tom, ako správne nakonfigurovať server, prosím navštívte {linkStart} dokumentáciu {linkEnd}",
    "Autoconfig file detected" : "Detekovaný súbor automatickej konfigurácie",
    "The setup form below is pre-filled with the values from the config file." : "Inštalačný formulár nižšie je vopred vyplnený hodnotami z konfiguračného súboru.",
    "Create administration account" : "Vytvoriť účet administrátora",
    "Administration account name" : "Názov účtu administrátora",
    "Administration account password" : "Heslo účtu administrátora",
    "Storage & database" : "Úložisko & databáza",
    "Data folder" : "Priečinok dát",
    "Database configuration" : "Konfigurácia Databáze",
    "Database type" : "Typ databázy",
    "Only {firstAndOnlyDatabase} is available." : "Je dostupná iba {firstAndOnlyDatabase}",
    "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
    "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
    "Performance warning" : "Varovanie o výkone",
    "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
    "Database connection" : "Pripojenie k databáze",
    "Database user" : "Používateľ databázy",
    "Database password" : "Heslo databázy",
    "Database name" : "Meno databázy",
    "Database tablespace" : "Tabuľkový priestor databázy",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
    "Database host" : "Server databázy",
    "localhost" : "localhost",
    "Installing …" : "Inštalujem ...",
    "Install" : "Inštalovať",
    "Need help?" : "Potrebujete pomoc?",
    "See the documentation" : "Pozri dokumentáciu",
    "{name} version {version} and above" : "{name} verzie {version} alebo vyššej",
    "This browser is not supported" : "Tento prehliadač nie je podporovaný",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Váš prehliadač nie je podporovaný. Inovujte na novšiu alebo podporovanú verziu.",
    "Continue with this unsupported browser" : "Pokračovať s nepodporovaným prehliadačom",
    "Supported versions" : "Podporované verzie",
    "Search {types} …" : "Vyhľadať {types} ...",
    "Choose {file}" : "Vyberte {file}",
    "Choose" : "Vybrať",
    "Copy to {target}" : "Kopírovať do {target}",
    "Copy" : "Kopírovať",
    "Move to {target}" : "Presunúť do {target}",
    "Move" : "Presunúť",
    "OK" : "OK",
    "read-only" : "iba na čítanie",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konflikt súboru","{count} konflikty súboru","{count} konfliktov súboru","{count} konfliktov súboru"],
    "One file conflict" : "Jeden konflikt súboru",
    "New Files" : "Nové súbory",
    "Already existing files" : "Už existujúce súbory",
    "Which files do you want to keep?" : "Ktoré súbory chcete ponechať?",
    "If you select both versions, the copied file will have a number added to its name." : "Ak zvolíte obe verzie, názov nakopírovaného súboru bude doplnený o číslo.",
    "Cancel" : "Zrušiť",
    "Continue" : "Pokračovať",
    "(all selected)" : "(všetko vybrané)",
    "({count} selected)" : "({count} vybraných)",
    "Error loading file exists template" : "Chyba pri nahrávaní šablóny existencie súboru",
    "Saving …" : "Ukladanie …",
    "Groups" : "Skupiny",
    "Group list is empty" : "Zoznam skupín je prázdny",
    "Unable to retrieve the group list" : "Nie je možné načítať zoznam skupín",
    "seconds ago" : "pred sekundami",
    "Connection to server lost" : "Stratené spojenie so serverom",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
    "Add to a project" : "Pridať do projektu",
    "Show details" : "Zobraziť podrobnosti",
    "Hide details" : "Skryť podrobnosti",
    "Rename project" : "Premenovať projekt",
    "Failed to rename the project" : "Nepodarilo sa premenovať projekt",
    "Failed to create a project" : "Nepodarilo sa vytvoriť projekt",
    "Failed to add the item to the project" : "Nepodarilo sa pridať položku do projektu",
    "Connect items to a project to make them easier to find" : "Priradiť položky do projektu, aby sa ľahšie hľadali",
    "Type to search for existing projects" : "Hľadajte v existujúcich projektoch",
    "New in" : "Nové v",
    "View changelog" : "Zobraziť súhrn zmien",
    "Close \"{dialogTitle}\" dialog" : "Zatvoriť okno \"{dialogTitle}\"",
    "Email length is at max (255)" : "E-mailová správa má maximálnu veľkosť (255)",
    "Clipboard not available, please copy manually" : "Schránka nie je k dispozícii, prosím skopírujte ručne",
    "Personal" : "Osobné",
    "Accounts" : "Účty",
    "Admin" : "Administrácia",
    "Help" : "Pomoc",
    "Access forbidden" : "Prístup odmietnutý",
    "You are not allowed to access this page." : "Nie je vám povolený prístup na túto stránku.",
    "Back to %s" : "Späť na %s",
    "Page not found" : "Stránka nenájdená",
    "The page could not be found on the server or you may not be allowed to view it." : "Túto stránku sa nepodarilo na serveri nájsť alebo nemáte oprávnenie na jej zobrazenie.",
    "Too many requests" : "Priveľa požiadavok",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
    "Error" : "Chyba",
    "Internal Server Error" : "Vnútorná chyba servera",
    "The server was unable to complete your request." : "Server nebol schopný dokončiť vašu žiadosť.",
    "If this happens again, please send the technical details below to the server administrator." : "Ak sa to stane opäť, nižšie zašlite technické podrobnosti správcovi servera.",
    "More details can be found in the server log." : "Viac nájdete v logu servera.",
    "For more details see the documentation ↗." : "Viac podrobností nájdete vdokumentácii ↗.",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdialená adresa: %s",
    "Request ID: %s" : "ID požiadavky: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Správa: %s",
    "File: %s" : "Súbor: %s",
    "Line: %s" : "Riadok: %s",
    "Trace" : "Trasa",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Vyzerá, že sa snažíte preinštalovať svoj Nextcloud. Avšak v priečinku s konfiguráciou chýba súbor CAN_INSTALL. Ak chcete pokračovať, tak ho vytvorte.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nie je možné odstrániť súbor CAN_INSTALL z priečinka s konfiguráciou. Je potrebné ho odstrániť ručne.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Táto aplikácia vyžaduje JavaScript, aby správne fungovala. Prosím, {linkstart}zapnite si JavaScript{linkend} a obnovte stránku",
    "Skip to main content" : "Prejsť na hlavný obsah",
    "Skip to navigation of app" : "Preskočiť do navigácie apky",
    "Go to %s" : "Prejsť na %s",
    "Get your own free account" : "Získajte zdarma svoj vlastný účet",
    "Previous" : "Predchádzajúce",
    "Two-factor authentication" : "Dvojfázové overovanie",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vylepšená bezpečnosť je pre váš účet povolená. Vyberte druhý faktor overenia:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedá sa načítať minimálne jeden z vašich povolených spôsobov na dvojfázové overovanie. Kontaktujte prosím správcu systému.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dvojfaktorová autentifikácia je vyžadovaná ale nebola nakonfigurovaná pre Váš účet.  Kontaktujte administrátora pre ďalšiu asistenciu.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Vo vašom účte sa vynucuje dvojfázové overovanie, ale ešte nebolo nakonfigurované. Pokračujte prosím do nastavenia dvojfázového overovania.",
    "Set up two-factor authentication" : "Nastaviť dvojfázové overovanie",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dvojfaktorová autentifikácia je vyžadovaná ale nebola nakonfigurovaná pre Váš účet.  Použite jeden zo záložných kódov na prihlásenie alebo kontaktujte administrátora pre ďalšiu asistenciu.",
    "Use backup code" : "Použiť záložný kód",
    "Cancel login" : "Zruš prihlasovanie",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Pre váš účet je vynútená zvýšená bezpečnosť. Vyberte si poskytovateľa, ktorého chcete nastaviť:",
    "Error while validating your second factor" : "Chyba počas overovania druhého faktora",
    "Access through untrusted domain" : "Prístup cez nedôveryhodnú doménu",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontaktujte svojho správcu. Ak ste administrátorom vy, upravte nastavenie \"trusted_domains\" v config/config.php ako napríklad v config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Viac informácií o konfigurácii je možné nájsť v %1$s dokumentácii %2$s.",
    "App update required" : "Je nutná aktualizácia aplikácie",
    "%1$s will be updated to version %2$s" : "%1$s bude zaktualizovaný na verziu %2$s.",
    "The following apps will be updated:" : "Aktualizujú sa nasledujúce aplikácie:",
    "These incompatible apps will be disabled:" : "Tieto nekompatibilné aplikácie budú vypnuté:",
    "The theme %s has been disabled." : "Téma %s bola zakázaná.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
    "Start update" : "Spustiť aktualizáciu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby nedošlo k vypršaniu časového limitu vo väčších inštaláciách, môžete namiesto toho použiť nasledujúci príkaz z inštalačného priečinka:",
    "Detailed logs" : "Podrobné záznamy",
    "Update needed" : "Aktualizácia je potrebná",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 účtami.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pre pomoc si pozrite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentáciu</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Viem, že ak budem pokračovať v aktualizácii prostredníctvom webového rozhrania, existuje riziko, že žiadosť prekročí časový limit a môže spôsobiť stratu dát, ale mám zálohu a viem, ako obnoviť svoju inštanciu v prípade zlyhania.",
    "Upgrade via web on my own risk" : "Aktualizovať cez web na vlastné riziko",
    "Maintenance mode" : "Mód údržby",
    "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
    "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
    "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
    "unknown text" : "neznámy text",
    "Hello world!" : "Ahoj svet!",
    "sunny" : "slnečno",
    "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
    "Hello {name}" : "Vitaj {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto sú výsledky vášho vyhľadávania <script>alert(1)</script></strong>",
    "new" : "nový",
    "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov","stiahnuť %n súborov"],
    "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky",
    "Searching …" : "Hľadá sa…",
    "Logging in …" : "Prihlasujem ...",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
    "Loading apps …" : "Načítavanie apiek...",
    "Installing apps …" : "Inštalácia apiek...",
    "Loading your contacts …" : "Načítavam vaše kontakty...",
    "Looking for {term} …" : "Hľadá sa výraz {term}...",
    "Search contacts …" : "Prehľadať kontakty...",
    "Loading more results …" : "Načítava sa viac výsledkov …",
    "Search {types} …" : "Vyhľadať {types}",
    "Saving …" : "Ukladá sa...",
    "Very weak password" : "Veľmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Priemerné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Silné heslo",
    "No action available" : "NIe sú dostupné žiadne akcie",
    "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
    "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
    "Restricted" : "Obmedzené",
    "Delete" : "Zmazať",
    "Rename" : "Premenovať",
    "Collaborative tags" : "Štítky pre spoluprácu",
    "No tags found" : "Štítky sa nenašli",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Vytvoriť účet administrátora</strong>",
    "New admin account name" : "Názov nového účtu administrátora",
    "New admin password" : "Nové heslo administrátora",
    "Show password" : "Zobraziť heslo",
    "Toggle password visibility" : "Prepnúť viditeľnosť hesla",
    "Configure the database" : "Nastaviť databázu",
    "Only %s is available." : "Je dostupný len %s.",
    "Database account" : "Databázový účet",
    "Installing …" : "Inštalujem ...",
    "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
    "Currently logged in as %1$s (%2$s)." : "Momentálne ste prihlásený ako %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
